[![Build Status](https://travis-ci.com/uriva/gamla.svg?branch=master)](https://travis-ci.com/uriva/gamla)

Gamla is a functional programming library for python.

`pip install gamla`

To deploy: `python setup.py sdist bdist_wheel; twine upload dist/*; rm dist/ -r;`
